-- author: DD ModPassion
-- copyright (C): DD ModPassion, All Rights Reserved
-- version: Farming Simulator 25
WorkAreaAddon = {}
function WorkAreaAddon.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(WorkArea, specializations)
end
function WorkAreaAddon.registerEventListeners(vehicleType)
    SpecializationUtil.registerEventListener(vehicleType, "onDraw", WorkAreaAddon)
    SpecializationUtil.registerEventListener(vehicleType, "onRegisterActionEvents", WorkAreaAddon)
end
function WorkAreaAddon:onDraw(isActiveForInput, isActiveForInputIgnoreSelection, isSelected)
    if isActiveForInputIgnoreSelection then
        local configKey = string.format("vehicle.workAreas.workAreaConfigurations.workAreaConfiguration(%d)", self.configurations.workArea - 1)
        local configName = self.xmlFile:getValue(configKey .. "#name", nil, customEnvironment, false)
        local params = self.xmlFile:getValue(configKey .. "#params")
        if params ~= nil then
            params = params:split("|")
            for i = 1, #params do
                params[i] = g_i18n:convertText(params[i], customEnvironment)
            end
            configName = string.format(configName, unpack(params))
        end
        g_currentMission:addExtraPrintText(string.format(g_i18n:getText("action_workModeSelected"), configName))
    end
end
function WorkAreaAddon:onRegisterActionEvents(isActiveForInput, isActiveForInputIgnoreSelection)
    if self.isClient then
        local spec = self.spec_workArea
        self:clearActionEventsTable(spec.actionEvents)
        if isActiveForInput then
            local _, actionEventId = self:addActionEvent(spec.actionEvents, InputAction.IMPLEMENT_EXTRA4, self, WorkAreaAddon.actionEventChangeWorkArea, false, true, false, true, nil)
            g_inputBinding:setActionEventTextPriority(actionEventId, GS_PRIO_HIGH)
            g_inputBinding:setActionEventText(actionEventId, g_i18n:getText("input_TOGGLE_WORKMODE"))
        end
    end
end
function WorkAreaAddon.actionEventChangeWorkArea(self, actionName, inputValue, callbackState, isAnalog)
    local spec = self.spec_workArea
    local configurationId = Utils.getNoNil(self.configurations.workArea, 1)
    if configurationId < 3 then
        configurationId = configurationId + 1
    else
        configurationId = 1
    end
    local configKey = string.format("vehicle.workAreas.workAreaConfigurations.workAreaConfiguration(%d)", configurationId - 1)
    spec.workAreas = {}
	local i = 0
	while true do
		local key = string.format("%s.workArea(%d)", configKey, i)
		if not self.xmlFile:hasProperty(key) then
			break
		end
		local workArea = {}
		if self:loadWorkAreaFromXML(workArea, self.xmlFile, key) then
			table.insert(spec.workAreas, workArea)
			workArea.index = #spec.workAreas
			self:updateWorkAreaWidth(workArea.index)
		end
		i = i + 1
	end
	spec.workAreaByType = {}
	for _, area in pairs(spec.workAreas) do
		if spec.workAreaByType[area.type] == nil then
			spec.workAreaByType[area.type] = {}
		end
		table.insert(spec.workAreaByType[area.type], area)
	end
    self.configurations.workArea = configurationId
end